Update of /cvsroot/alsa/alsa-kernel/include
In directory sc8-pr-cvs1:/tmp/cvs-serv14712/include
Modified Files:
asound.h timer.h
Log Message:
Minor cleanups for timer API
Index: timer.h
===================================================================
RCS file: /cvsroot/alsa/alsa-kernel/include/timer.h,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -r1.12 -r1.13
--- timer.h 2 Mar 2003 10:44:13 -0000 1.12
+++ timer.h 2 Mar 2003 15:03:38 -0000 1.13
@@ -73,7 +73,6 @@
unsigned long resolution; /* average timer resolution for one tick in
nsec */
unsigned long resolution_min; /* minimal resolution */
unsigned long resolution_max; /* maximal resolution */
- unsigned long resolution_step; /* step for resolution */
unsigned long ticks; /* max timer ticks per interrupt */
/* -- low-level functions -- */
int (*open) (snd_timer_t * timer);
@@ -82,6 +81,7 @@
int (*start) (snd_timer_t * timer);
int (*stop) (snd_timer_t * timer);
int (*set_resolution) (snd_timer_t * timer, unsigned long resolution);
+ int (*precise_resolution) (snd_timer_t * timer, unsigned long *num, unsigned
long *den);
};
struct _snd_timer {
-------------------------------------------------------
This sf.net email is sponsored by:ThinkGeek
Welcome to geek heaven.
http://thinkgeek.com/sf
_______________________________________________
Alsa-cvslog mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/alsa-cvslog
Index: asound.h
===================================================================
RCS file: /cvsroot/alsa/alsa-kernel/include/asound.h,v
retrieving revision 1.24
retrieving revision 1.25
diff -u -r1.24 -r1.25
--- asound.h 2 Mar 2003 10:44:13 -0000 1.24
+++ asound.h 2 Mar 2003 15:03:38 -0000 1.25
@@ -575,11 +575,10 @@
unsigned char id[64]; /* timer identification */
unsigned char name[80]; /* timer name */
unsigned long ticks; /* maximum ticks between interrupts */
- unsigned long resolution; /* average resolution in ns */
- unsigned long resolution_min; /* minimal resolution in ns */
- unsigned long resolution_max; /* maximal resolution in ns */
- unsigned long resolution_step; /* resolution step in ns */
- unsigned int instances; /* active timer instances */
+ unsigned long resolution; /* average period resolution in ns */
+ unsigned long resolution_min; /* minimal period resolution in ns */
+ unsigned long resolution_max; /* maximal period resolution in ns */
+ unsigned int clients; /* active timer clients */
unsigned char reserved[32];
};
@@ -591,7 +590,9 @@
struct sndrv_timer_gstatus {
struct sndrv_timer_id tid; /* requested timer ID */
- unsigned long resolution; /* current resolution in ns */
+ unsigned long resolution; /* current period resolution in ns */
+ unsigned long resolution_num; /* precise current period resolution (in
seconds) - numerator */
+ unsigned long resolution_den; /* precise current period resolution (in
seconds) - denominator */
unsigned char reserved[32];
};
@@ -606,7 +607,7 @@
unsigned char id[64]; /* timer identificator */
unsigned char name[80]; /* timer name */
unsigned long ticks; /* maximum ticks between interrupts */
- unsigned long resolution; /* average resolution in ns */
+ unsigned long resolution; /* average period resolution in ns */
unsigned char reserved[64]; /* reserved */
};
@@ -623,7 +624,7 @@
struct sndrv_timer_status {
struct timespec tstamp; /* Timestamp - last update */
- unsigned int resolution; /* current resolution in ns */
+ unsigned int resolution; /* current period resolution in ns */
unsigned int lost; /* counter of master tick lost */
unsigned int overrun; /* count of read queue overruns */
unsigned int queue; /* used queue size */